@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import NamedTuple, Optional, Union, List
 from typing_extensions import TypedDict
-from tim.types import Logs, Status
+from tim.types import Logs, Status, SortDirection
 
 
 class BaseUnit(Enum):
@@ -31,7 +31,7 @@ class DatasetWorkspace(TypedDict):
   name: str
 
 
-class DatasetMetaData(TypedDict):
+class Dataset(TypedDict):
   id: str
   latestVersion: LatestVersion
   createdAt: str
@@ -45,6 +45,35 @@ class DatasetMetaData(TypedDict):
   name: str
 
 
+class Variables(TypedDict):
+  name: str
+  minimumValue: float
+  maximumValue: float
+  firstTimestamp: str
+  lastTimestamp: str
+  missingObservations: int
+  type: str
+  averageValue: float
+
+
+class DatasetListVersion(TypedDict):
+  id: str
+  createdAt: str
+  status: str
+
+
+class DatasetVersion(TypedDict):
+  id: str
+  estimatedSamplingPeriod: str
+  size: int
+  numberOfObservations: int
+  firstTimestamp: str
+  lastTimestamp: str
+  variables: List[Variables]
+  createdAt: str
+  status: str
+
+
 class CSVSeparator(Enum):
   SEMICOLON = ';'
   TAB = ' '
@@ -72,5 +101,17 @@ class UploadCsvResponse(TypedDict):
 
 class UploadDatasetResponse(NamedTuple):
   id: str
-  metaData: Optional[DatasetMetaData]
+  metaData: Optional[Dataset]
   logs: List[Logs]
+
+
+class DatasetListPayload(TypedDict, total=False):
+  offset: int
+  limit: int
+  workspaceId: str
+  sort: SortDirection
+
+
+class DatasetVersionListPayload(TypedDict, total=False):
+  offset: int
+  limit: int
