@@ -36,3 +36,16 @@ class StatusResponse(TypedDict):
   progress: float
   memory: int
   CPU: int
+
+
+class ObjId(TypedDict):
+  id: str
+
+
+class SortDirection(Enum):
+  CREATED_AT_DESC = '-createdAt'
+  CREATED_AT_ASC = '+createdAt'
+  UPDATED_AT_DESC = '-updatedAt'
+  UPDATED_AT_ASC = '+updatedAt'
+  TITLE_DESC = '-title'
+  TITLE_ASC = '+title'
